@@ -4,7 +4,12 @@ import pytest
 
 
 @pytest.mark.parametrize(
-    'mod', ['carbonplan', 'carbonplan.data', 'carbonplan.forests', 'carbonplan.styles']
+    'mod',
+    [
+        'carbonplan',
+        'carbonplan.data',
+        'carbonplan.styles',
+    ],
 )
 def test_import_submodules(mod):
     mod = importlib.import_module(mod)
